==> insighttoolkit5_5.2.1.orig.tar.xz: InsightToolkit-5.2.1/Modules/IO/NIFTI/test/LittleEndian_img.h <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef __LittleEndian_img_h
#define __LittleEndian_img_h

const unsigned char LittleEndian_img[] = {
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67,
  0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66,
  0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66
};

#endif

==> insighttoolkit5_5.4.5.orig.tar.xz: InsightToolkit-5.4.5/Modules/IO/NIFTI/test/LittleEndian_img.h <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         https://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef LittleEndian_img_h
#define LittleEndian_img_h

const unsigned char LittleEndian_img[] = {
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67,
  0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 16,  67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80,  67, 0, 0, 80,  67,
  0, 0, 80,  67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66,
  0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 48,  67, 0, 0, 48,  67,
  0, 0, 48,  67, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 64,  66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66
};

#endif
